#!/bin/bash

echo "----> Installing Tick Stack"
# Define tickstack software versions
INFLUX_VERSION=1.5.2
INFLUX_CHECKSUM=42fede7b497bdf30d4eb5138db218d1add986fca4fce4a8bcd9c7d6dabaf572a

KAPACITOR_VERSION=1.4.1
KAPACITOR_CHECKSUM=eea9b215f241906570eafe3857e1d4c5

CHRONOGRAF_VERSION=1.4.4.2
CHRONOGRAF_CHECKSUM=eea6915aa6db8f134fcd3b095e863b773bfb3a16a26e346dd65904a07df97963

apt-get update
echo "----> Installing wget"
apt-get install -y wget

# install influx
echo "----> Installing InfluxDB"
wget https://dl.influxdata.com/influxdb/releases/influxdb_${INFLUX_VERSION}_amd64.deb 2> /dev/null
sha256sum influxdb_${INFLUX_VERSION}_amd64.deb | grep $INFLUX_CHECKSUM > /dev/null
if [ $? == 1 ]; then
	echo "influx download failed checksum"
	exit 1
fi
dpkg -i influxdb_${INFLUX_VERSION}_amd64.deb

# install kapacitor
echo "----> Installing Kapacitor"
wget https://dl.influxdata.com/kapacitor/releases/kapacitor_${KAPACITOR_VERSION}_amd64.deb 2> /dev/null
md5sum kapacitor_${KAPACITOR_VERSION}_amd64.deb | grep $KAPACITOR_CHECKSUM > /dev/null
if [ $? == 1 ]; then
	echo "Kapacitor download failed checksum"
	exit 1
fi
dpkg -i kapacitor_${KAPACITOR_VERSION}_amd64.deb

# install Chronograf
echo "----> Installing Chronograph"
wget https://dl.influxdata.com/chronograf/releases/chronograf_${CHRONOGRAF_VERSION}_amd64.deb 2> /dev/null
sha256sum chronograf_${CHRONOGRAF_VERSION}_amd64.deb | grep $CHRONOGRAF_CHECKSUM > /dev/null
if [ $? == 1 ]; then
	echo "Chronograf download failed checksum"
	exit 1
fi
dpkg -i chronograf_${CHRONOGRAF_VERSION}_amd64.deb

systemctl start influxdb
systemctl start kapacitor
systemctl start chronograf

# wait for kapacitor to start
while ! nc -z localhost 9092
do
  echo "Waiting for kapacitor port 9092 to be ready on localhost..."
  sleep 1
done

# define the TICK script templates within Kapacitor
echo "----> Creating alert templates in Kapacitor"
cd ${REPO_ROOT}/src/service/clmcservice/resources/TICKscript
for template_file in *.tick; do
    template_id=$(basename ${template_file} .tick)
    echo ${template_id} ${template_file}
    kapacitor define-template ${template_id} -tick ${template_file}
done

